==> v1.0.0.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/controller/VisualDataController.java <==
/**
 * 
 */
package org.springblade.visual.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;

import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.system.client.DataPermClient;
import org.springblade.visual.dto.VisualDto;
import org.springblade.visual.entity.VisualClassify;
import org.springblade.visual.entity.VisualComponent;
import org.springblade.visual.entity.VisualData;
import org.springblade.visual.enums.VisualTypeEnum;
import org.springblade.visual.service.VisualClassifyService;
import org.springblade.visual.service.VisualComponentService;
import org.springblade.visual.service.VisualDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("visual/data")
@Api(value = "大屏模版接口", tags = "大屏模版接口")
public class VisualDataController extends BladeController {

	@Autowired
	private VisualDataService visualDataService;
	
	@Autowired
	private VisualComponentService visualComponentService;
	
	@Autowired
	private VisualClassifyService visualCategoryService;

	@Autowired
	private DataPermClient dataPermClient;
	
	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入visual")
	public R<VisualData> detail(VisualData visualData) {
		VisualData detail = visualDataService.getOne(Condition.getQueryWrapper(visualData));
		if(detail == null) {
			return R.fail("大屏模版不存在");
		}
		//查询大屏使用的所有组件
		LambdaQueryWrapper<VisualComponent> queryWrapper = Wrappers.<VisualComponent>lambdaQuery().eq(VisualComponent::getVisualId, detail.getId());
		List<Integer> componentIdList = visualComponentService.listObjs(queryWrapper, a -> Integer.valueOf(a.toString()));
		detail.setComponentIds(componentIdList);
		return R.data(detail);
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "列表")
	public R<IPage<VisualData>> list(VisualData visualData, Query query){
		Long userId = getUser().getUserId();
		LambdaQueryWrapper<VisualData> queryWrapper = Condition.getQueryWrapper(visualData).lambda().eq(VisualData::getVisualType, VisualTypeEnum.GENERAL).orderByAsc(VisualData::getOrderIndex);
		Boolean checkSuperPermRet = dataPermClient.checkSuperPermission(getUser().getUserId());
		if(checkSuperPermRet == null || !checkSuperPermRet) {
			queryWrapper.and(t ->{
				t.eq(VisualData::getCreateUser, userId)
				.or().inSql(VisualData::getId, "select a.visual_id from visual_data_permission a inner join data_permission_user b on a.data_perm_id = b.data_perm_id where b.user_id = " + userId)
				.or().eq(VisualData::getPublicStatus, 1);
			});
		}
		return R.data(visualDataService.page(Condition.getPage(query), queryWrapper));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@GetMapping("/myList")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "我的收藏列表")
	public R<IPage<VisualData>> mylist(VisualData visualData, Query query){
		visualData.setCreateUser(getUser().getUserId());
		visualData.setVisualType(VisualTypeEnum.FAVOURITE);
		return R.data(visualDataService.page(Condition.getPage(query), Condition.getQueryWrapper(visualData).lambda().orderByAsc(VisualData::getOrderIndex)));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "更新大屏（仅更新大屏的数据，不传递参数不更新）")
	public R<String> update(@RequestBody VisualData visualData) {
		if(visualData.getCategory() != null) {
			int count = visualCategoryService.count(Wrappers.<VisualClassify>lambdaQuery().eq(VisualClassify::getParentId, visualData.getCategory()));
			if(count > 0) {
				return R.fail("该分类下有子分类，不能放置大屏。");
			}
		}
		return R.status(visualDataService.updateById(visualData));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 * @throws IOException 
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "新增或更新大屏", notes = "返回值：大屏ID")
	@ApiResponse(message = "大屏ID", code = 200)
	public R<Integer> submit(@RequestBody String value) throws IOException {
		String decoderStr = new String(Base64.getDecoder().decode(value), "utf-8");
		VisualDto visualDto = JSON.parseObject(decoderStr, VisualDto.class);
		return R.data(visualDataService.doSaveOrUpdate(visualDto, getUser()));
	}
	
	/**
	 * 
	 * @param ids
	 * @return
	 */
	@PostMapping("/delete")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "删除大屏")
	public R<String> delete(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		visualDataService.doRemove(Func.toIntList(ids));
		return R.success("删除成功");
	}
	
	/**
	 * 拷贝 可视化表
	 */
	@PostMapping("/copy")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "拷贝大屏模板")
	public R<Integer> copy(
			@ApiParam(value = "原大屏id", required = true) @RequestParam Integer id,
			@ApiParam(value = "新分类id", required = false) @RequestParam(required = false) Integer newCategoryId) {
		return R.data(visualDataService.doCopyGeneral(id, newCategoryId, getUser()));
	}
	
	/**
	 * 调整顺序
	 * @return
	 */
	@PostMapping("/adjustOrder")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "调整顺序", notes = "传入大屏ID列表【切记：保证大屏顺序】")
	public R<String> uptOrder(@ApiParam(value = "主键集合  1,2,3", required = true) @RequestParam String ids) {
		List<VisualData> entityList = new ArrayList<VisualData>();
		List<Integer> visualIdList = Func.toIntList(ids);
		Integer[] indexArr = {1};
		visualIdList.forEach(itemId -> {
			VisualData data = new VisualData();
			data.setId(itemId);
			data.setOrderIndex(indexArr[0]++);
			entityList.add(data);
		});
		return R.status(visualDataService.updateBatchById(entityList));
	}
}

==> v1.1.1.tar.gz: platomix-gmetry-bi/platomix-gmetry-bi-api/src/main/java/org/springblade/visual/controller/VisualDataController.java <==
/**
 * 
 */
package org.springblade.visual.controller;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Base64;
import java.util.List;

import org.springblade.core.boot.ctrl.BladeController;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.system.client.DataPermClient;
import org.springblade.visual.dto.VisualDto;
import org.springblade.visual.entity.VisualClassify;
import org.springblade.visual.entity.VisualComponent;
import org.springblade.visual.entity.VisualData;
import org.springblade.visual.enums.VisualTypeEnum;
import org.springblade.visual.service.VisualClassifyService;
import org.springblade.visual.service.VisualComponentService;
import org.springblade.visual.service.VisualDataService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;

import cn.hutool.core.collection.CollectionUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("visual/data")
@Api(value = "大屏模版接口", tags = "大屏模版接口")
public class VisualDataController extends BladeController {

	@Autowired
	private VisualDataService visualDataService;
	
	@Autowired
	private VisualComponentService visualComponentService;
	
	@Autowired
	private VisualClassifyService visualCategoryService;

	@Autowired
	private DataPermClient dataPermClient;
	
	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入visual")
	public R<VisualData> detail(VisualData visualData) {
		VisualData detail = visualDataService.getOne(Condition.getQueryWrapper(visualData));
		if(detail == null) {
			return R.fail("大屏模版不存在");
		}
		//查询大屏使用的所有组件
		LambdaQueryWrapper<VisualComponent> queryWrapper = Wrappers.<VisualComponent>lambdaQuery().select(VisualComponent::getId).eq(VisualComponent::getVisualId, detail.getId());
		List<Integer> componentIdList = visualComponentService.listObjs(queryWrapper, a -> Integer.valueOf(a.toString()));
		detail.setComponentIds(componentIdList);
		return R.data(detail);
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "列表")
	public R<IPage<VisualData>> list(VisualData visualData, Query query){
		Long userId = getUser().getUserId();
		LambdaQueryWrapper<VisualData> queryWrapper = Condition.getQueryWrapper(visualData).lambda().eq(VisualData::getVisualType, VisualTypeEnum.GENERAL).orderByAsc(VisualData::getOrderIndex);
		Boolean checkSuperPermRet = dataPermClient.checkSuperPermission(getUser().getUserId());
		if(checkSuperPermRet == null || !checkSuperPermRet) {
			queryWrapper.and(t ->{
				t.eq(VisualData::getCreateUser, userId)
				.or().inSql(VisualData::getId, "select a.visual_id from visual_data_permission a inner join data_permission_user b on a.data_perm_id = b.data_perm_id where b.user_id = " + userId)
				.or().eq(VisualData::getPublicStatus, 1);
			});
		}
		return R.data(visualDataService.page(Condition.getPage(query), queryWrapper));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@GetMapping("/myList")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "我的收藏列表")
	public R<IPage<VisualData>> mylist(VisualData visualData, Query query){
		visualData.setCreateUser(getUser().getUserId());
		visualData.setVisualType(VisualTypeEnum.FAVOURITE);
		return R.data(visualDataService.page(Condition.getPage(query), Condition.getQueryWrapper(visualData).lambda().orderByAsc(VisualData::getOrderIndex)));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "更新大屏（仅更新大屏的数据，不传递参数不更新）")
	public R<String> update(@RequestBody VisualData visualData) {
		if(visualData.getCategory() != null) {
			int count = visualCategoryService.count(Wrappers.<VisualClassify>lambdaQuery().eq(VisualClassify::getParentId, visualData.getCategory()));
			if(count > 0) {
				return R.fail("该分类下有子分类，不能放置大屏。");
			}
		}
		return R.status(visualDataService.updateById(visualData));
	}
	
	/**
	 * 
	 * @param visualData
	 * @return
	 * @throws IOException 
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "新增或更新大屏", notes = "返回值：大屏ID")
	@ApiResponse(message = "大屏ID", code = 200)
	public R<Integer> submit(@RequestBody String value) throws IOException {
		String decoderStr = new String(Base64.getDecoder().decode(value), "utf-8");
		VisualDto visualDto = JSON.parseObject(decoderStr, VisualDto.class);
		return R.data(visualDataService.doSaveOrUpdate(visualDto, getUser()));
	}
	
	/**
	 * 
	 * @param ids
	 * @return
	 */
	@PostMapping("/delete")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "删除大屏")
	public R<String> delete(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		visualDataService.doRemove(Func.toIntList(ids));
		return R.success("删除成功");
	}
	
	/**
	 * 拷贝 可视化表
	 */
	@PostMapping("/copy")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "拷贝大屏模板")
	public R<Integer> copy(
			@ApiParam(value = "原大屏id", required = true) @RequestParam Integer id,
			@ApiParam(value = "新分类id", required = false) @RequestParam(required = false) Integer newCategoryId,
			@ApiParam(value = "大屏类型(默认不传递：GENERAL)", required = false) @RequestParam(required = false, value = "visualType", defaultValue = "GENERAL") VisualTypeEnum visualType) {
		List<Integer> visualIdList = visualDataService.doCopy(CollectionUtil.newHashSet(id), newCategoryId, null, null, visualType, getUser(), "[副本]");
		return R.data(CollectionUtil.isNotEmpty(visualIdList) ? visualIdList.get(0) : null);
	}
	
	/**
	 * 调整顺序
	 * @return
	 */
	@PostMapping("/adjustOrder")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "调整顺序", notes = "传入大屏ID列表【切记：保证大屏顺序】")
	public R<String> uptOrder(@ApiParam(value = "主键集合  1,2,3", required = true) @RequestParam String ids) {
		List<VisualData> entityList = new ArrayList<VisualData>();
		List<Integer> visualIdList = Func.toIntList(ids);
		for(int i = 0; i < visualIdList.size(); i++) {
			VisualData data = new VisualData();
			data.setId(visualIdList.get(i));
			data.setOrderIndex(i);
			entityList.add(data);
		}
		return R.status(visualDataService.updateBatchById(entityList));
	}
}
